@@ -17,6 +17,8 @@ class PromptHandler:
     def __init__(self):
         self.templates = PromptTemplates()
     
+   
+
     async def handle_prompt(self, name: str, arguments: Dict[str, str] = None) -> types.GetPromptResult:
         """
         Route và xử lý prompt calls
@@ -33,6 +35,8 @@ class PromptHandler:
         try:
             if name == "check_lgedv":
                 return await self._handle_lgedv_check()
+            elif name == "check_static_analysis":
+                return await self._handle_lge_static_check()
             elif name == "check_misra_cpp":
                 return await self._handle_misra_cpp_check()
             elif name == "check_autosar":  
@@ -59,6 +63,8 @@ class PromptHandler:
                 return await self._handle_reset_resource_check_prompt(arguments)
             if name == "reset_race_check":
                 return await self._handle_reset_race_check_prompt(arguments)
+            elif name == "check_design":
+                return await self._handle_design_check(arguments)
             else:
                 raise ValueError(f"Unknown prompt: {name}")
                 
@@ -111,6 +117,53 @@ class PromptHandler:
         logger.info("LGEDV check prompt completed")
         return result
     
+    async def _handle_lge_static_check(self) -> types.GetPromptResult:
+        """Handle LGE Static Analysis code checking prompt"""
+        import os
+        prompt_lang = os.environ.get("prompt_lang", "en")
+        if prompt_lang == "vi":
+            prompt = (
+                "Bạn là chuyên gia phân tích tĩnh C++. Hãy phân tích file hiện tại để phát hiện vi phạm các quy tắc LGE Static Analysis.\n"
+                "Nếu chưa có file rule, hãy gọi fetch_static_analysis_rule từ MCP server.\n"
+                "Luôn sử dụng bộ quy tắc LGE Static Analysis mới nhất vừa fetch để phân tích, không dùng rule cũ hoặc built-in.\n"
+                "Hãy ghi rõ bộ rule nào đang dùng trong báo cáo.\n\n"
+                "**YÊU CẦU PHÂN TÍCH:**\n"
+                "- Tìm TẤT CẢ vi phạm quy tắc trên\n"
+                "- Tập trung vào vi phạm LGE Static Analysis\n"
+                "- Ghi rõ số hiệu rule (VD: ARRAY_VS_SINGLETON, ATOMICITY, BAD_ALLOC_ARITHMETIC, v.v.)\n"
+                "- Kiểm tra mọi dòng code, kể cả unreachable, dead code, return sớm, magic number\n"
+                "- Kiểm tra mọi điểm acquire/release resource, mọi exit point, mọi function/method\n"
+                "- Đưa ra code fix cụ thể cho từng lỗi\n"
+                "- Ghi số dòng code gốc trong báo cáo\n\n"
+                "**ĐỊNH DẠNG KẾT QUẢ:**\n"
+                "Với mỗi lỗi:\n"
+                "## 🚨 Vấn đề [#]: [Mô tả ngắn]\n\n"
+                "**Rule vi phạm:** [SỐ HIỆU] - [Mô tả rule]\n\n"
+                "**Vị trí:** [tên hàm hoặc global/unknown]\n\n"
+                "**Mức độ:** [Critical/High/Medium/Low]\n\n"
+                "**Code hiện tại:**\n"
+                "```cpp\n[code lỗi]\n```\n"
+                "**Code đã sửa:**\n"
+                "```cpp\n[code đúng]\n```\n"
+                "**Giải thích:** [Vì sao vi phạm và cách sửa]\n\n"
+                "**Lưu ý:** Nếu cần toàn bộ file code đã fix, hãy yêu cầu rõ ràng."
+            )
+        else:
+            prompt = self.templates.get_lge_static_analysis_prompt()  # Cần thêm template này
+        
+        messages = [
+            types.PromptMessage(
+                role="user",
+                content=types.TextContent(type="text", text=prompt),
+            )
+        ]
+        result = types.GetPromptResult(
+            messages=messages,
+            description="A prompt for LGE Static Analysis rule on current file.",
+        )
+        logger.info("LGE Static Analysis check prompt completed")
+        return result
+
     async def _handle_misra_cpp_check(self) -> types.GetPromptResult:
         """Handle MISRA code checking prompt"""
         import os
@@ -605,6 +658,112 @@ class PromptHandler:
                 ],
                 description="Reset race analysis error.",
             )
+        
+    async def _handle_design_check(self, arguments=None) -> types.GetPromptResult:
+        import os
+        from lgedv.modules.config import get_src_dir, get_req_dir, get_api_base_dirs, get_module_api, get_framework_dir, get_report_dir
+        
+        prompt_lang = os.environ.get("prompt_lang", "en")
+        
+        # Lấy tham số feature từ arguments dict
+        feature = None
+        if arguments and isinstance(arguments, dict) and "feature" in arguments:
+            feature = arguments["feature"]
+        
+        logger.info(f"[check_design] Feature argument: {feature}")
+        
+        if prompt_lang == "vi":
+            # Prompt tiếng Việt đầy đủ
+            prompt = (
+                "Bạn là chuyên gia phân tích thiết kế hệ thống nhúng ô tô.\n"
+                "Nhiệm vụ của bạn: Đánh giá sơ đồ trình tự (sequence diagram) trong thiết kế đính kèm (file hình ảnh) về mức độ đáp ứng yêu cầu"
+            )
+            
+            # Thêm feature nếu có
+            if feature:
+                prompt += f" cho feature {feature}"
+            
+            prompt += ", xác thực API, và độ robust.\n"
+            
+            # Tiếp tục với phần còn lại
+            prompt += (
+                "\n\n**QUY TRÌNH PHÂN TÍCH:**\n"
+                f"1. Phân tích kỹ yêu cầu về feature"
+            )
+            
+            if feature:
+                prompt += f" {feature}"
+            
+            prompt += (
+                " trong tài liệu requirement (file markdown đính kèm).\n"
+                "2. Trích xuất đầy đủ các thành phần, API call, và luồng tương tác từ sequence diagram.\n"
+                "3. Đối chiếu từng API call với ngữ cảnh ứng dụng, interface để xác thực tính hợp lệ.\n"
+                "4. So sánh từng bước thiết kế với yêu cầu, kiểm tra điểm thiếu/phủ sóng hoặc chưa rõ ràng. Đặc biệt, cần phân tích kỹ các trường hợp lỗi (error case), timeout, và các tình huống bất thường có thể xảy ra trong thực tế.\n"
+                "5. Đánh giá chi tiết khả năng xử lý lỗi, chiến lược recovery, logic fallback, và quản lý trạng thái của hệ thống. Nêu rõ các nhánh xử lý lỗi, cơ chế phục hồi, và đảm bảo hệ thống không rơi vào trạng thái bất định.\n"
+                "6. Đề xuất cải tiến robust design, bổ sung các bước xử lý lỗi còn thiếu, và xây dựng sơ đồ PlantUML sequence cải tiến với nhánh error/recovery rõ ràng nếu cần.\n\n"
+                "## 🔍 Phân tích thiết kế hiện tại\n"
+                "### Đánh giá luồng trình tự\n"
+                "- Thành phần: [liệt kê]\n"
+                "- Luồng thông điệp: [phân tích]\n"
+                "- Chuyển trạng thái: [phân tích]\n\n"
+                "### Kết quả xác thực API\n"
+                "**✅ API hợp lệ:**\n"
+                "- `ClassName::method()` - Tìm thấy trong [ngữ cảnh]\n"
+                "**❌ API thiếu:**\n"
+                "- `UnknownClass::method()` - Không tìm thấy, cần bổ sung\n"
+                "**⚠️ API mơ hồ:**\n"
+                "- `CommonName::method()` - Tìm thấy ở nhiều ngữ cảnh, cần làm rõ\n\n"
+                "### Đáp ứng yêu cầu\n"
+                "| Mã yêu cầu | Mô tả | Trạng thái | Ghi chú |\n"
+                "|-----------|-------|------------|--------|\n"
+                "| REQ-001 | [nội dung] | ✅/❌/⚠️ | [ghi chú] |\n\n"
+                "## ❌ Vấn đề nghiêm trọng\n"
+                "- Thiếu phủ sóng yêu cầu\n"
+                "- API không hợp lệ hoặc thiếu\n"
+                "- Thiếu robust (xử lý lỗi, timeout, fallback, trạng thái)\n"
+                "## 🚀 Giải pháp thiết kế nâng cao\n"
+                "### Chiến lược tích hợp API\n"
+                "- Dùng API có sẵn ở mọi ngữ cảnh nếu có thể\n"
+                "- Sửa API hiện có nếu cần\n"
+                "- Chỉ đề xuất API mới khi thực sự cần thiết, phải giải thích rõ\n\n"
+                "### Kế hoạch đáp ứng yêu cầu\n"
+                "- Với mỗi yêu cầu thiếu, nêu rõ thay đổi thiết kế cần thực hiện\n\n"
+                "### Đề xuất improved design\n"
+                "Vui lòng trình bày improved design cho thiết kế hiện tại bằng sequence diagram chuẩn PlantUML.\n"
+                "```plantuml\n"
+                "@startuml\n"
+                "title Enhanced Design\n"
+                "' Add enhanced design here\n"
+                "' Include error handling and robustness\n"
+                "@enduml\n"
+                "```\n"
+            )
+            
+            if feature:
+                prompt += f" - {feature}"
+            
+            prompt += (
+                "\n\n"
+                "' Add enhanced design here\n"
+                "' Include error handling and robustness\n"
+                "@enduml\n"
+                "```\n"
+            )
+        else:            
+            prompt = self.templates.get_design_verification_prompt(feature)
+
+        messages = [
+            types.PromptMessage(
+                role="user",
+                content=types.TextContent(type="text", text=prompt),
+            )
+        ]
+        result = types.GetPromptResult(
+            messages=messages,
+            description="A prompt for design verification and improvement.",
+        )
+        logger.info("Design verification prompt completed")
+        return result
      
     def _format_resource_leak_summary(self, leaks: list) -> str:
         """Format a summary of resource leaks by type and severity"""
