@@ -9,7 +9,8 @@ from mcp.types import TextContent
 
 from lgedv.modules.rule_fetcher import (
     fetch_misra_cpp_rule, fetch_lgedv_rule, fetch_certcpp_rule,
-    fetch_custom_rule, fetch_autosar_rule, fetch_misra_c_rule
+    fetch_custom_rule, fetch_autosar_rule, fetch_misra_c_rule,
+    fetch_static_analysis_rule
 )
 from lgedv.modules.file_utils import list_source_files
 
@@ -19,6 +20,7 @@ from lgedv.analyzers.resource_analyzer import ResourceAnalyzer
 from lgedv.modules.config import setup_logging, get_src_dir
 from lgedv.modules.persistent_storage import PersistentTracker
 from lgedv.handlers.requirement_handler import handle_requirement_analysis
+from lgedv.handlers.interface_handler import get_interface
 
 import pprint
 from datetime import datetime
@@ -31,6 +33,7 @@ import sys
 import subprocess
 from lgedv.modules import report_rule,report_race, report_resource,report_leak
 
+from lgedv.handlers.markitdown_handler import markitdown_handler
 
 def get_lgedv_cache_dir():
     if platform.system().lower().startswith("win"):
@@ -44,7 +47,7 @@ class ToolHandler:
 
     def __init__(self):
         self.memory_tracker = PersistentTracker(analysis_type="memory_analysis")
-
+        
     async def handle_tool_call(self, name: str, arguments: dict) -> List[Union[
         types.TextContent, types.ImageContent, types.AudioContent, types.EmbeddedResource
     ]]:
@@ -67,6 +70,8 @@ class ToolHandler:
                 return await self._handle_fetch_misra_cpp_rule(arguments)
             elif name == "fetch_lgedv_rule":
                 return await self._handle_fetch_lgedv_rule(arguments)
+            elif name == "fetch_static_analysis_rule":
+                return await self._handle_fetch_static_analysis_rule(arguments)
             elif name == "fetch_certcpp_rule":
                 return await self._handle_fetch_certcpp_rule(arguments)
             elif name == "fetch_custom_rule":
@@ -100,10 +105,12 @@ class ToolHandler:
                 return await self._handle_report_race_condition(arguments)
             elif name == "report_resource_leak":
                 return await self._handle_report_resource_leak(arguments)
-            elif name == "report_leak":
-                return await self._handle_report_leak(arguments)
             elif name == "analyze_requirement":
                 return await self._handle_analyze_requirement(arguments)
+            elif name == "get_interface":
+                return await self._handle_get_interface(arguments)
+            elif name == "convert_md":
+                return await self._handle_convert_markitdown(arguments)
             else:
                 logger.error(f"Unknown tool: {name}")
                 raise ValueError(f"Unknown tool: {name}")
@@ -113,6 +120,111 @@ class ToolHandler:
             logger.exception(f"Error in tool handler for {name}: {e}")
             raise
     
+    async def _handle_convert_markitdown(self, arguments: dict) -> List[types.TextContent]:
+        """Handle markitdown conversion - supports both single file and batch directory conversion"""
+        logger.info(f"Converting document(s) with markitdown: {arguments}")
+        
+        try:            
+            result = await markitdown_handler.handle_convert_markitdown(arguments)
+            
+            if result and len(result) > 0:
+                first_result = result[0]
+                
+                if "error" in first_result:
+                    response_text = f"❌ Conversion Error: {first_result['error']}"
+                    
+                elif first_result.get('batch_conversion', False):
+                    # Batch conversion result
+                    directory = first_result.get('directory', 'unknown')
+                    total_files = first_result.get('total_files_found', 0)
+                    converted_count = first_result.get('converted_count', 0)
+                    error_count = first_result.get('error_count', 0)
+                    
+                    response_text = f"📁 **Batch Conversion Completed**\n\n"
+                    response_text += f"**Directory**: `{directory}`\n"
+                    response_text += f"**Files Found**: {total_files}\n"
+                    response_text += f"**✅ Successfully Converted**: {converted_count}\n"
+                    response_text += f"**❌ Errors**: {error_count}\n\n"
+                    
+                    if converted_count > 0:
+                        response_text += "**📝 Conversion Details:**\n\n"
+                        
+                        results = first_result.get('results', [])
+                        for i, file_result in enumerate(results[:10], 1):  # Show first 10 results
+                            if file_result.get('success', False):
+                                input_file = os.path.basename(file_result.get('input_file', ''))
+                                output_file = os.path.basename(file_result.get('output_file', ''))
+                                content_length = file_result.get('content_length', 0)
+                                response_text += f"{i}. ✅ `{input_file}` → `{output_file}` ({content_length} chars)\n"
+                            else:
+                                input_file = os.path.basename(file_result.get('input_file', ''))
+                                error = file_result.get('error', 'Unknown error')
+                                response_text += f"{i}. ❌ `{input_file}` - Error: {error}\n"
+                        
+                        if len(results) > 10:
+                            response_text += f"\n... and {len(results) - 10} more files\n"
+                            
+                    else:
+                        response_text += "**ℹ️ No files were converted successfully.**\n"
+                        
+                else:
+                    # Single file conversion result  
+                    uri = first_result.get('uri', 'unknown')
+                    content_length = first_result.get('content_length', 0)
+                    markdown_content = first_result.get('markdown_content', '')
+                    metadata = first_result.get('metadata', {})
+                    
+                    response_text = f"✅ Successfully converted document from: {uri}\n\n"
+                    response_text += f"📊 **Conversion Stats:**\n"
+                    response_text += f"- Content length: {content_length} characters\n"
+                    
+                    if metadata:
+                        response_text += f"- Metadata: {metadata}\n"
+                    
+                    response_text += f"\n📝 **Markdown Content:**\n\n{markdown_content}"
+            else:
+                response_text = "❌ No result returned from markitdown conversion"
+                
+            return [types.TextContent(type="text", text=response_text)]
+            
+        except Exception as e:
+            logger.error(f"Error in _handle_convert_markitdown: {e}")
+            return [types.TextContent(type="text", text=f"❌ Error during conversion: {str(e)}")]
+    
+    async def _handle_get_interface(self, arguments: dict):
+        """
+        Handle get interface tool call
+        Nếu không có arguments hoặc không có 'dir', lấy từ module_api trong config
+        """
+        # Import config function để lấy module_api
+        from lgedv.modules.config import get_module_api
+        
+        # Kiểm tra và lấy dir_path
+        if not arguments or 'dir' not in arguments or not arguments.get('dir'):
+            # Lấy từ module_api trong mcp.json
+            dir_path = get_module_api()
+            logger.info(f"[get_interface] No dir parameter provided, using module_api from config: {dir_path}")
+        else:
+            # Sử dụng dir từ arguments
+            dir_path = arguments.get("dir")
+            logger.info(f"[get_interface] Using dir from arguments: {dir_path}")
+        
+        # Kiểm tra dir_path có hợp lệ không
+        if not dir_path:
+            error_msg = "❌ Lỗi: Không có thư mục nào được chỉ định và không có module_api trong config"
+            logger.error(error_msg)
+            return [types.TextContent(type="text", text=error_msg)]
+        
+        # Gọi hàm get_interface với dir_path
+        try:
+            result = get_interface(dir_path)
+            logger.info(f"[get_interface] Successfully analyzed interface in: {dir_path}")
+            return [types.TextContent(type="text", text=json.dumps(result, ensure_ascii=False, indent=2))]
+        except Exception as e:
+            error_msg = f"❌ Lỗi khi phân tích interface: {str(e)}"
+            logger.error(error_msg)
+            return [types.TextContent(type="text", text=error_msg)]
+
     async def _handle_fetch_misra_cpp_rule(self, arguments: dict) -> List[types.TextContent]:
         """Handle fetch_misra_cpp_rule tool"""
         url = arguments.get("url")
@@ -127,6 +239,13 @@ class ToolHandler:
         logger.info(f"fetch_lgedv_rule completed for url: {url}")
         return result
     
+    async def _handle_fetch_static_analysis_rule(self, arguments: dict) -> List[types.TextContent]:
+        """Handle fetch_static_analysis_rule tool"""
+        url = arguments.get("url")
+        result = await fetch_static_analysis_rule(url)
+        logger.info(f"fetch_static_analysis_rule completed for url: {url}")
+        return result
+
     async def _handle_fetch_certcpp_rule(self, arguments: dict) -> List[types.TextContent]:
         """Handle fetch_certcpp_rule tool"""
         url = arguments.get("url")
@@ -1525,15 +1644,23 @@ class ToolHandler:
             )]
         
     async def _handle_analyze_requirement(self, arguments: dict) -> List[types.TextContent]:
-            """Handle analyze_requirement tool"""
-            try:
-                dir_path = arguments.get("dir")
-                if not dir_path:
-                    return [types.TextContent(type="text", text="Error: dir_path is required")]
-                
-                result = handle_requirement_analysis(dir_path)
-                import json
-                return [types.TextContent(type="text", text=json.dumps(result, ensure_ascii=False, indent=2))]
-            except Exception as e:
-                logger.error(f"Error in analyze_requirement: {e}")
-                return [types.TextContent(type="text", text=f"Error: {str(e)}")]
\ No newline at end of file
+        """Handle analyze_requirement tool"""
+        try:
+            # Import hàm lấy req_dir từ config
+            from lgedv.modules.config import get_req_dir
+
+            dir_path = arguments.get("dir")
+            if not dir_path:
+                dir_path = get_req_dir()
+                logger.info(f"[analyze_requirement] No dir parameter provided, using req_dir from config: {dir_path}")
+
+            if not dir_path:
+                return [types.TextContent(type="text", text="Error: dir_path is required and req_dir not found in config")]
+
+            result = handle_requirement_analysis(dir_path)
+            return [types.TextContent(type="text", text=json.dumps(result, ensure_ascii=False, indent=2))]
+        except Exception as e:
+            logger.error(f"Error in analyze_requirement: {e}")
+            return [types.TextContent(type="text", text=f"Error: {str(e)}")]
+            
+    
\ No newline at end of file
