@@ -9,7 +9,7 @@ from mcp.server.lowlevel import Server
 from pydantic import FileUrl
 import os
 import sys
-
+import json
 # Import modules từ package structure mới
 from lgedv.modules.config import RESOURCE_FILES, CUSTOM_RULE_URL, setup_logging
 from lgedv.handlers.tool_handlers import ToolHandler
@@ -17,6 +17,7 @@ from lgedv.handlers.prompt_handlers import PromptHandler
 from lgedv.handlers.resource_handler import get_all_resources
 from lgedv.modules.persistent_storage import PersistentTracker, reset_all_analysis
 
+from lgedv.modules.config import is_premium
 
 # Setup logging
 logger = setup_logging()
@@ -29,9 +30,12 @@ logger = setup_logging()
     default="stdio",
     help="Transport type",
 )
+
 def main(port: int, transport: str):
     """Main entry point for the MCP server"""
     try:
+        premium_enabled = is_premium()
+        logger.info(f"Premium mode: {'enabled' if premium_enabled else 'disabled'}")
         logger.info("Server started and ready to receive requests")
         logger.info(f"Starting server with transport: {transport}, port: {port}")
         
@@ -56,6 +60,16 @@ def main(port: int, transport: str):
             types.TextContent | types.ImageContent | types.AudioContent | types.EmbeddedResource
         ]:
             """Route tool calls to appropriate handler"""
+            # Danh sách premium tools
+            premium_tools = ["convert_md", "get_interface", "analyze_requirement"]
+            
+            # Kiểm tra premium cho các premium tools
+            if name in premium_tools and not premium_enabled:
+                return [types.TextContent(
+                    type="text",
+                    text=f"❌ Tool '{name}' requires premium subscription. Please set 'premium': true in mcp.json env section."
+                )]
+            
             return await tool_handler.handle_tool_call(name, arguments)
 
         # Register tool list handler
@@ -63,7 +77,8 @@ def main(port: int, transport: str):
         async def list_tools() -> list[types.Tool]:
             """List all available tools"""
             logger.info("list_tools called")
-            return [
+            tools = [
+                # Các tool miễn phí
                 types.Tool(
                     name="fetch_misra_cpp_rule",
                     description="Fetches the MISRA C++ 2008 rule markdown from remote server.",
@@ -90,6 +105,19 @@ def main(port: int, transport: str):
                         },
                     },
                 ),
+                types.Tool(
+                    name="fetch_static_analysis_rule",
+                    description="Fetches the Static Analysis rule markdown from remote server.",
+                    inputSchema={
+                        "type": "object",
+                        "properties": {
+                            "url": {
+                                "type": "string",
+                                "description": "URL to fetch LGE Static Analysis rule (optional, default is preset)",
+                            }
+                        },                        
+                    },
+                ),
                 types.Tool(
                     name="fetch_certcpp_rule",
                     description="Fetches the CERT C++ rule markdown from remote server.",
@@ -142,19 +170,19 @@ def main(port: int, transport: str):
                         },
                     },
                 ),
-                types.Tool(
-                    name="list_source_files",
-                    description="List all .cpp files in the current src_dir or given directory.",
-                    inputSchema={
-                        "type": "object",
-                        "properties": {
-                            "dir_path": {
-                                "type": "string",
-                                "description": "Directory to search for .cpp files (optional, default is src_dir or cwd)",
-                            }
-                        },
-                    },
-                ),
+                # types.Tool(
+                #     name="list_source_files",
+                #     description="List all .cpp files in the current src_dir or given directory.",
+                #     inputSchema={
+                #         "type": "object",
+                #         "properties": {
+                #             "dir_path": {
+                #                 "type": "string",
+                #                 "description": "Directory to search for .cpp files (optional, default is src_dir or cwd)",
+                #             }
+                #         },
+                #     },
+                # ),
                 types.Tool(
                     name="get_src_context",
                     description="Get the content of all files in the current given directory as a single response for context.",
@@ -166,7 +194,8 @@ def main(port: int, transport: str):
                                 "description": "Directory to search for code files.",
                             }
                         },
-                    },
+                        "required": []
+                    },                    
                 ),
                 types.Tool(
                     name="detect_races",
@@ -232,32 +261,92 @@ def main(port: int, transport: str):
                     description="Generate .html report for resource leak analysis from .md files in report_dir.",
                     inputSchema={"type": "object", "properties": {}}
                 ),
-                types.Tool(
-                    name="analyze_requirement",
-                    description="analyze requirement from .md files in specified directory",
-                    inputSchema={
-                        "type": "object",
-                        "properties": {
-                            "dir": {
-                                "type": "string",
-                                "description": "path to directory containing .md files",
-                            }
-                        },
-                        "required": ["dir"]
-                    }
-                )
             ]
+            
+            # Premium tools - chỉ thêm nếu premium enabled
+            if premium_enabled:
+                premium_tools = [
+                    types.Tool(
+                        name="convert_md",
+                        description="Convert documents (PDF, PowerPoint, Excel, Word) to markdown format - supports single file or batch directory conversion with advanced filtering",
+                        inputSchema={
+                            "type": "object",
+                            "properties": {
+                                "uri": {
+                                    "type": "string",
+                                    "description": "URI to convert single file (http:, https:, file:, or data: scheme)",
+                                },
+                                "dir": {
+                                    "type": "string", 
+                                    "description": "Directory path for batch conversion of all supported documents"
+                                },
+                                "ext": {
+                                    "type": "string",
+                                    "description": "Comma-separated extensions to filter (e.g., 'pdf,docx,pptx')"
+                                },
+                                "recursive": {
+                                    "type": "boolean",
+                                    "description": "Scan subdirectories recursively (default: false)"
+                                },
+                                "output": {
+                                    "type": "string",
+                                    "description": "Custom output directory path (default: same as input directory)"
+                                }
+                            },
+                            "anyOf": [
+                                {"required": ["uri"]},
+                                {"required": ["dir"]}
+                            ]
+                        },
+                    ),
+                    types.Tool(
+                        name="get_interface",
+                        description="Quét tất cả thư mục interface, trích xuất API từ .h, .hpp, .cpp",
+                        inputSchema={
+                            "type": "object",
+                            "properties": {
+                                "dir": {
+                                    "type": "string",
+                                    "description": "Thư mục chứa các file interface để quét API",
+                                }
+                            },
+                            "required": []
+                        }
+                    ),
+                    types.Tool(
+                        name="analyze_requirement",
+                        description="analyze requirement from .md files in specified directory",
+                        inputSchema={
+                            "type": "object",
+                            "properties": {
+                                "dir": {
+                                    "type": "string",
+                                    "description": "path to directory containing .md files",
+                                }
+                            },
+                            "required": []
+                        }
+                    ),
+                ]
+                tools.extend(premium_tools)
+                
+            return tools
 
         # Register prompt list handler
         @app.list_prompts()
         async def list_prompts() -> list[types.Prompt]:
             """List all available prompts"""
             logger.info("list_prompts called")
-            return [
+            prompts = [
+                # Free prompts
                 types.Prompt(
                     name="check_lgedv",
                     description="check code violations based on LGEDV rule guide for current file."
                 ),
+                types.Prompt(
+                    name="check_static_analysis",
+                    description="Analyze code for Static Analysis rule violations."
+                ),
                 types.Prompt(
                     name="check_misra_cpp",
                     description="check code violations based on MISRA C++ 2008 rule guide for current file."
@@ -311,11 +400,48 @@ def main(port: int, transport: str):
                     description="Reset race analysis cache."
                 ),
             ]
-
+            
+            # Premium prompts - chỉ thêm nếu premium enabled
+            if premium_enabled:
+                premium_prompts = [
+                    types.Prompt(
+                        name="check_design",                        
+                        description="System design verification",
+                        arguments=[
+                            types.PromptArgument(
+                                name="feature",
+                                description="Feature name to focus analysis on (e.g., 'callback waiting')",
+                                required=False,
+                            ),
+                        ],
+                    ),
+                ]
+                prompts.extend(premium_prompts)
+                
+            return prompts
+        
         # Register prompt handler
         @app.get_prompt()
         async def get_prompt(name: str, arguments: dict[str, str] | None = None) -> types.GetPromptResult:
             """Route prompt calls to appropriate handler"""
+            # Danh sách premium prompts
+            premium_prompts = ["check_design"]
+            
+            # Kiểm tra premium cho các premium prompts
+            if name in premium_prompts and not premium_enabled:
+                return types.GetPromptResult(
+                    description="Premium Feature Required",
+                    messages=[
+                        types.PromptMessage(
+                            role="user",
+                            content=types.TextContent(
+                                type="text",
+                                text=f"❌ Prompt '{name}' requires premium subscription. Please set 'premium': true in mcp.json env section."
+                            ),
+                        ),
+                    ],
+                )
+            
             return await prompt_handler.handle_prompt(name, arguments)
 
         # Register resource list handler
